summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/util/utl_err.cpp
diff options
context:
space:
mode:
authornobody <nobody@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2004-09-16 21:19:02 +0000
committernobody <nobody@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2004-09-16 21:19:02 +0000
commit40fdc8a404e75ab03b68cc62e9987cf208fd8c30 (patch)
tree37d9c4d3abe4aefd8a34ed797883dd2cd4862ca7 /TAO/TAO_IDL/util/utl_err.cpp
parentc254b281f1b9a4ca19dd0c3ee73a0654a7718909 (diff)
downloadATCD-40fdc8a404e75ab03b68cc62e9987cf208fd8c30.tar.gz
This commit was manufactured by cvs2svn to create branchtypecode-overhaul
'typecode-overhaul'.
Diffstat (limited to 'TAO/TAO_IDL/util/utl_err.cpp')
-rw-r--r--TAO/TAO_IDL/util/utl_err.cpp36
1 files changed, 20 insertions, 16 deletions
diff --git a/TAO/TAO_IDL/util/utl_err.cpp b/TAO/TAO_IDL/util/utl_err.cpp
index 51b2afc7e7c..98a9f56c6ff 100644
--- a/TAO/TAO_IDL/util/utl_err.cpp
+++ b/TAO/TAO_IDL/util/utl_err.cpp
@@ -199,8 +199,6 @@ error_string (UTL_Error::ErrorCode c)
return "module must contain at least one declaration: ";
case UTL_Error::EIDL_BACK_END:
return "back end: ";
- case UTL_Error::EIDL_ILLEGAL_INFIX:
- return "illegal infix operator in expression";
}
return 0;
@@ -945,7 +943,26 @@ UTL_Error::abstract_support_error (UTL_ScopedName *v,
idl_global->set_err_count (idl_global->err_count () + 1);
}
-// Report illegal component or home support of local interface.
+// Report illegal component or home support of abstract interface.
+void
+UTL_Error::concrete_interface_expected (UTL_ScopedName *c,
+ UTL_ScopedName *i)
+{
+ idl_error_header (EIDL_CANT_SUPPORT,
+ idl_global->lineno (),
+ idl_global->filename ());
+ ACE_ERROR ((LM_ERROR,
+ " component or home "));
+ c->dump (*ACE_DEFAULT_LOG_STREAM);
+ ACE_ERROR ((LM_ERROR,
+ " attempts to support an abstract interface: "));
+ i->dump (*ACE_DEFAULT_LOG_STREAM);
+ ACE_ERROR ((LM_ERROR,
+ "\n"));
+ idl_global->set_err_count (idl_global->err_count () + 1);
+}
+
+// Report illegal component or home support of abstract interface.
void
UTL_Error::unconstrained_interface_expected (UTL_ScopedName *c,
UTL_ScopedName *i)
@@ -1339,19 +1356,6 @@ UTL_Error::back_end (long lineno,
idl_error_header (EIDL_BACK_END,
lineno,
s);
- ACE_ERROR ((LM_ERROR,
- "\n"));
- idl_global->set_err_count (idl_global->err_count () + 1);
-}
-
-void
-UTL_Error::illegal_infix (void)
-{
- idl_error_header (EIDL_ILLEGAL_INFIX,
- idl_global->lineno (),
- idl_global->filename ());
- ACE_ERROR ((LM_ERROR,
- "\n"));
idl_global->set_err_count (idl_global->err_count () + 1);
}